@@ -47,11 +47,11 @@ sub scrape {
                         grep {/DoCoMo/}
                         split m[(?:&nbsp;|<br\s*/>|\r|\n)]i, $col
                     )[0]; # XXX: 複数あるときは一番最初のがブラウザ
+                    $col =~ s/ *（.+//;
+                    $col =~ s/<[^><]+>//g; # remove tags
+                    $col =~ s/(&#xA0.*)$//;
                     $col =~ s/^\s*//;
                     $col =~ s/\s*$//;
-                    $col =~ s/<[^><]+>//g; # remove tags
-                    $col =~ s/ （.+//;
-                    $col =~ s/(&#xA0.*)$//;
                     return $col;
                 }
             }->();
